==> spip_3.2.11.orig.tar.xz: plugins-dist/sites/lang/sites_da.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/sites?lang_cible=da
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// A
	'avis_echec_syndication_01' => 'Syndikering mislykket: enten er den valgte datakilde utilgængelig eller også indeholder den ingen artikler.',
	'avis_echec_syndication_02' => 'Syndication mislykket: kunne ikke få forbindelse til den valgte datakilde.',
	'avis_site_introuvable' => 'Webstedet ikke fundet',
	'avis_site_syndique_probleme' => 'Advarsel: syndikering med dette websted er stødt på et problem; derfor afbrydes systemet midlertidigt. Kontroller adressen på webstedets syndikeringsfil (<b>@url_syndic@</b>), og prøv at få adgang til data igen.', # MODIF
	'avis_sites_probleme_syndication' => 'Disse websteder har problemer med syndikering',
	'avis_sites_syndiques_probleme' => 'Disse syndikerede sider giver problemer',

	// B
	'bouton_radio_modere_posteriori' => 'Efterfølgende godkendelse (bidrag er straks synlige men en administrator kan senere slette dem)', # MODIF
	'bouton_radio_modere_priori' => 'Forhåndsgodkendelse', # MODIF
	'bouton_radio_non_syndication' => 'Ingen syndikering',
	'bouton_radio_syndication' => 'Syndikering:',

	// E
	'entree_adresse_fichier_syndication' => 'Adresse på syndikeringsfil:',
	'entree_adresse_site' => '<b>URL på websted</b> [Skal oplyses]',
	'entree_description_site' => 'Beskrivelse af websted',

	// F
	'form_prop_nom_site' => 'Webstedets navn',

	// I
	'icone_modifier_site' => 'Ret dette websted',
	'icone_referencer_nouveau_site' => 'Ny webstedshenvisning',
	'icone_voir_sites_references' => 'Vis links',
	'info_1_site' => '1 websted',
	'info_a_valider' => '[at kontrollere]',
	'info_bloquer_lien' => 'bloker dette link',
	'info_derniere_syndication' => 'Sidste syndikering af dette websted blev udført den',
	'info_liens_syndiques_1' => 'syndikerede links',
	'info_liens_syndiques_2' => 'afventer godkendelse.',
	'info_nom_site_2' => '<b>Webstedets navn</b> [Skal udfyldes]',
	'info_panne_site_syndique' => 'Syndikeret side er ude af trit',
	'info_probleme_grave' => 'problem med',
	'info_question_proposer_site' => 'Hvem kan foreslå henvisninger til websteder?',
	'info_retablir_lien' => 'Genopret dette link',
	'info_site_attente' => 'Websted afventer godkendelse',
	'info_site_propose' => 'Websted sendt til godkendelse den:',
	'info_site_reference' => 'Online henvisning',
	'info_site_refuse' => 'Websted afvist',
	'info_site_syndique' => 'Dette websted er syndikeret...', # MODIF
	'info_site_valider' => 'Websteder der afventer godkendelse',
	'info_sites_referencer' => 'Link til websted',
	'info_sites_refuses' => 'Afviste websteder',
	'info_statut_site_1' => 'Dette websted er:',
	'info_statut_site_2' => 'Offentliggjort',
	'info_statut_site_3' => 'Indsendt',
	'info_statut_site_4' => 'I papirkurven', # MODIF
	'info_syndication' => 'syndikering:',
	'info_syndication_articles' => 'bidrag',
	'item_bloquer_liens_syndiques' => 'Afspær syndikerede links indtil de er godkendt',
	'item_gerer_annuaire_site_web' => 'Vedligehold katalog over websteder',
	'item_non_bloquer_liens_syndiques' => 'Undlad at spærre links til syndikerede websteder',
	'item_non_gerer_annuaire_site_web' => 'Vedligehold ikke katalog over websteder',
	'item_non_utiliser_syndication' => 'Benyt ikke automatisk syndikering',
	'item_utiliser_syndication' => 'Benyt automatisk syndikering',

	// L
	'lien_mise_a_jour_syndication' => 'Opdater nu',
	'lien_nouvelle_recuperation' => 'Forsøg at hente data igen',

	// T
	'texte_liens_sites_syndiques' => 'Links til syndikerede sider kan spærres på forhånd; følgende indstilling er standardindstillingen for syndikerede websteder, når de er oprettet.
			Det er således på trods heraf muligt at spærre hvert link individuelt eller at vælge for hver websted at spærre de links der kommer fra en givet websted.', # MODIF
	'texte_messages_publics' => 'Offentlige bidrag til artiklen:',
	'texte_non_fonction_referencement' => 'Du kan vælge ikke at bruge denne automatiske funktion, og selv angive de elementer, der er vigtige for webstedet...', # MODIF
	'texte_referencement_automatique' => '<b>Automatiserede webstedshenvisninger</b><br />
		Du kan hurtigt henvise til et websted ved nedenfor at angive dens URL eller adressen på dens datakilde. 
		SPIP vil automatisk indhente oplysninger om webstedet (titel, beskrivelse...).', # MODIF
	'texte_syndication' => 'Hvis webstedet tillader det, er det muligt automatisk at hente en oversigt over det
		seneste materiale. For at gøre dette, skal du igangsætte syndikering.
		<blockquote><i>Nogle webhoteller tillader ikke denne funktion.
		I så fald kan du ikke foretage indholdssyndikering fra dit websted.</i></blockquote>', # MODIF
	'titre_articles_syndiques' => 'Syndikerede artikler hentet på dette websted',
	'titre_dernier_article_syndique' => 'Senest syndikerede artikler',
	'titre_page_sites_tous' => 'Links til websteder',
	'titre_referencement_sites' => 'Henvisning og syndikering til websteder',
	'titre_site_numero' => 'WEBSTEDSNUMMER:',
	'titre_sites_proposes' => 'Indsendte websteder',
	'titre_sites_references_rubrique' => 'Websteder der henvises til i dette afsnit',
	'titre_sites_syndiques' => 'Syndikerede websteder',
	'titre_sites_tous' => 'Websteder der henvises til',
	'titre_syndication' => 'Webstedssyndikering'
);

==> spip_4.4.6+dfsg.orig.tar.xz: plugins-dist/sites/lang/sites_da.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/sites?lang_cible=da
// ** ne pas modifier le fichier **

return [

	// A
	'avis_echec_syndication_01' => 'Syndikering mislykket: enten er den valgte datakilde utilgængelig eller også indeholder den ingen artikler.',
	'avis_echec_syndication_02' => 'Syndication mislykket: kunne ikke få forbindelse til den valgte datakilde.',
	'avis_site_introuvable' => 'Webstedet ikke fundet',
	'avis_site_syndique_probleme' => 'Advarsel: syndikering med dette websted er stødt på et problem; derfor afbrydes systemet midlertidigt. Kontroller adressen på webstedets syndikeringsfil (<b>@url_syndic@</b>), og prøv at få adgang til data igen.', # MODIF
	'avis_sites_probleme_syndication' => 'Disse websteder har problemer med syndikering',
	'avis_sites_syndiques_probleme' => 'Disse syndikerede sider giver problemer',

	// B
	'bouton_radio_modere_posteriori' => 'Efterfølgende godkendelse (bidrag er straks synlige men en administrator kan senere slette dem)', # MODIF
	'bouton_radio_modere_priori' => 'Forhåndsgodkendelse', # MODIF
	'bouton_radio_non_syndication' => 'Ingen syndikering',
	'bouton_radio_syndication' => 'Syndikering:',

	// E
	'entree_adresse_fichier_syndication' => 'Adresse på syndikeringsfil:',
	'entree_adresse_site' => '<b>URL på websted</b> [Skal oplyses]',
	'entree_description_site' => 'Beskrivelse af websted',

	// F
	'form_prop_nom_site' => 'Webstedets navn',

	// I
	'icone_modifier_site' => 'Ret dette websted',
	'icone_referencer_nouveau_site' => 'Ny webstedshenvisning',
	'icone_voir_sites_references' => 'Vis links',
	'info_1_site' => '1 websted',
	'info_a_valider' => '[at kontrollere]',
	'info_bloquer_lien' => 'bloker dette link',
	'info_derniere_syndication' => 'Sidste syndikering af dette websted blev udført den',
	'info_liens_syndiques_1' => 'syndikerede links',
	'info_liens_syndiques_2' => 'afventer godkendelse.',
	'info_nom_site_2' => '<b>Webstedets navn</b> [Skal udfyldes]',
	'info_panne_site_syndique' => 'Syndikeret side er ude af trit',
	'info_probleme_grave' => 'problem med',
	'info_question_proposer_site' => 'Hvem kan foreslå henvisninger til websteder?',
	'info_retablir_lien' => 'Genopret dette link',
	'info_site_attente' => 'Websted afventer godkendelse',
	'info_site_propose' => 'Websted sendt til godkendelse den:',
	'info_site_reference' => 'Online henvisning',
	'info_site_refuse' => 'Websted afvist',
	'info_site_syndique' => 'Dette websted er syndikeret...', # MODIF
	'info_site_valider' => 'Websteder der afventer godkendelse',
	'info_sites_referencer' => 'Link til websted',
	'info_sites_refuses' => 'Afviste websteder',
	'info_statut_site_1' => 'Dette websted er:',
	'info_statut_site_2' => 'Offentliggjort',
	'info_statut_site_3' => 'Indsendt',
	'info_statut_site_4' => 'I papirkurven', # MODIF
	'info_syndication' => 'syndikering:',
	'info_syndication_articles' => 'bidrag',
	'item_bloquer_liens_syndiques' => 'Afspær syndikerede links indtil de er godkendt',
	'item_gerer_annuaire_site_web' => 'Vedligehold katalog over websteder',
	'item_non_bloquer_liens_syndiques' => 'Undlad at spærre links til syndikerede websteder',
	'item_non_gerer_annuaire_site_web' => 'Vedligehold ikke katalog over websteder',
	'item_non_utiliser_syndication' => 'Benyt ikke automatisk syndikering',
	'item_utiliser_syndication' => 'Benyt automatisk syndikering',

	// L
	'lien_mise_a_jour_syndication' => 'Opdater nu',
	'lien_nouvelle_recuperation' => 'Forsøg at hente data igen',

	// T
	'texte_liens_sites_syndiques' => 'Links til syndikerede sider kan spærres på forhånd; følgende indstilling er standardindstillingen for syndikerede websteder, når de er oprettet.
			Det er således på trods heraf muligt at spærre hvert link individuelt eller at vælge for hver websted at spærre de links der kommer fra en givet websted.', # MODIF
	'texte_messages_publics' => 'Offentlige bidrag til artiklen:',
	'texte_non_fonction_referencement' => 'Du kan vælge ikke at bruge denne automatiske funktion, og selv angive de elementer, der er vigtige for webstedet...', # MODIF
	'texte_referencement_automatique' => '<b>Automatiserede webstedshenvisninger</b><br />
		Du kan hurtigt henvise til et websted ved nedenfor at angive dens URL eller adressen på dens datakilde. 
		SPIP vil automatisk indhente oplysninger om webstedet (titel, beskrivelse...).', # MODIF
	'texte_syndication' => 'Hvis webstedet tillader det, er det muligt automatisk at hente en oversigt over det
		seneste materiale. For at gøre dette, skal du igangsætte syndikering.
		<blockquote><i>Nogle webhoteller tillader ikke denne funktion.
		I så fald kan du ikke foretage indholdssyndikering fra dit websted.</i></blockquote>', # MODIF
	'titre_articles_syndiques' => 'Syndikerede artikler hentet på dette websted',
	'titre_dernier_article_syndique' => 'Senest syndikerede artikler',
	'titre_page_sites_tous' => 'Links til websteder',
	'titre_referencement_sites' => 'Henvisning og syndikering til websteder',
	'titre_site_numero' => 'WEBSTEDSNUMMER:',
	'titre_sites_proposes' => 'Indsendte websteder',
	'titre_sites_references_rubrique' => 'Websteder der henvises til i dette afsnit',
	'titre_sites_syndiques' => 'Syndikerede websteder',
	'titre_sites_tous' => 'Websteder der henvises til',
	'titre_syndication' => 'Webstedssyndikering',
];
